Module instructions

Module instructions 

This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.

https://github.com/codama-idl/codama

Re-exports

pub use self::close_bundled_position::*;
pub use self::close_position::*;
pub use self::close_position_with_token_extensions::*;
pub use self::collect_fees::*;
pub use self::collect_fees_v2::*;
pub use self::collect_protocol_fees::*;
pub use self::collect_protocol_fees_v2::*;
pub use self::collect_reward::*;
pub use self::collect_reward_v2::*;
pub use self::decrease_liquidity::*;
pub use self::decrease_liquidity_v2::*;
pub use self::delete_position_bundle::*;
pub use self::delete_token_badge::*;
pub use self::increase_liquidity::*;
pub use self::increase_liquidity_v2::*;
pub use self::initialize_adaptive_fee_tier::*;
pub use self::initialize_config::*;
pub use self::initialize_config_extension::*;
pub use self::initialize_fee_tier::*;
pub use self::initialize_pool::*;
pub use self::initialize_pool_v2::*;
pub use self::initialize_pool_with_adaptive_fee::*;
pub use self::initialize_position_bundle::*;
pub use self::initialize_position_bundle_with_metadata::*;
pub use self::initialize_reward::*;
pub use self::initialize_reward_v2::*;
pub use self::initialize_tick_array::*;
pub use self::initialize_token_badge::*;
pub use self::lock_position::*;
pub use self::open_bundled_position::*;
pub use self::open_position::*;
pub use self::open_position_with_metadata::*;
pub use self::open_position_with_token_extensions::*;
pub use self::reset_position_range::*;
pub use self::set_collect_protocol_fees_authority::*;
pub use self::set_config_extension_authority::*;
pub use self::set_default_base_fee_rate::*;
pub use self::set_default_fee_rate::*;
pub use self::set_default_protocol_fee_rate::*;
pub use self::set_delegated_fee_authority::*;
pub use self::set_fee_authority::*;
pub use self::set_fee_rate::*;
pub use self::set_fee_rate_by_delegated_fee_authority::*;
pub use self::set_initialize_pool_authority::*;
pub use self::set_preset_adaptive_fee_constants::*;
pub use self::set_protocol_fee_rate::*;
pub use self::set_reward_authority::*;
pub use self::set_reward_authority_by_super_authority::*;
pub use self::set_reward_emissions::*;
pub use self::set_reward_emissions_super_authority::*;
pub use self::set_reward_emissions_v2::*;
pub use self::set_token_badge_authority::*;
pub use self::swap::*;
pub use self::swap_v2::*;
pub use self::transfer_locked_position::*;
pub use self::two_hop_swap::*;
pub use self::two_hop_swap_v2::*;
pub use self::update_fees_and_rewards::*;

Modules

close_bundled_position
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
close_position
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
close_position_with_token_extensions
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
collect_fees
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
collect_fees_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
collect_protocol_fees
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
collect_protocol_fees_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
collect_reward
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
collect_reward_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
decrease_liquidity
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
decrease_liquidity_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
delete_position_bundle
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
delete_token_badge
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
increase_liquidity
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
increase_liquidity_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_adaptive_fee_tier
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_config
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_config_extension
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_fee_tier
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_pool
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_pool_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_pool_with_adaptive_fee
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_position_bundle
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_position_bundle_with_metadata
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_reward
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_reward_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_tick_array
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
initialize_token_badge
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
lock_position
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
open_bundled_position
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
open_position
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
open_position_with_metadata
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
open_position_with_token_extensions
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
reset_position_range
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_collect_protocol_fees_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_config_extension_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_default_base_fee_rate
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_default_fee_rate
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_default_protocol_fee_rate
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_delegated_fee_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_fee_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_fee_rate
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_fee_rate_by_delegated_fee_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_initialize_pool_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_preset_adaptive_fee_constants
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_protocol_fee_rate
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_reward_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_reward_authority_by_super_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_reward_emissions
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_reward_emissions_super_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_reward_emissions_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
set_token_badge_authority
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
swap
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
swap_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
transfer_locked_position
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
two_hop_swap
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
two_hop_swap_v2
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
update_fees_and_rewards
This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.