DecreaseLiquidityCpiBuilder

Struct DecreaseLiquidityCpiBuilder 

pub struct DecreaseLiquidityCpiBuilder<'a, 'b> { /* private fields */ }
Instruction builder for DecreaseLiquidity via CPI.

Accounts:

  1. [writable] whirlpool
  2. [] token_program
  3. [signer] position_authority
  4. [writable] position
  5. [] position_token_account
  6. [writable] token_owner_account_a
  7. [writable] token_owner_account_b
  8. [writable] token_vault_a
  9. [writable] token_vault_b
  10. [writable] tick_array_lower
  11. [writable] tick_array_upper

Implementations

Source

impl<'a, 'b> DecreaseLiquidityCpiBuilder<'a, 'b>

pub fn new(program: &'b AccountInfo<'a>) -> Self

pub fn whirlpool(&mut self, whirlpool: &'b AccountInfo<'a>) -> &mut Self

pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self

pub fn position_authority( &mut self, position_authority: &'b AccountInfo<'a>, ) -> &mut Self

pub fn position(&mut self, position: &'b AccountInfo<'a>) -> &mut Self

pub fn position_token_account( &mut self, position_token_account: &'b AccountInfo<'a>, ) -> &mut Self

pub fn token_owner_account_a( &mut self, token_owner_account_a: &'b AccountInfo<'a>, ) -> &mut Self

pub fn token_owner_account_b( &mut self, token_owner_account_b: &'b AccountInfo<'a>, ) -> &mut Self

pub fn token_vault_a(&mut self, token_vault_a: &'b AccountInfo<'a>) -> &mut Self

pub fn token_vault_b(&mut self, token_vault_b: &'b AccountInfo<'a>) -> &mut Self

pub fn tick_array_lower( &mut self, tick_array_lower: &'b AccountInfo<'a>, ) -> &mut Self

pub fn tick_array_upper( &mut self, tick_array_upper: &'b AccountInfo<'a>, ) -> &mut Self

pub fn liquidity_amount(&mut self, liquidity_amount: u128) -> &mut Self

pub fn token_min_a(&mut self, token_min_a: u64) -> &mut Self

pub fn token_min_b(&mut self, token_min_b: u64) -> &mut Self

pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self

Add an additional account to the instruction.

pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self

Add additional accounts to the instruction.

Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not, and a bool indicating whether the account is a signer or not.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult