pub struct InitializePoolV2CpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for InitializePoolV2 via CPI.
Accounts:
[]whirlpools_config[]token_mint_a[]token_mint_b[]token_badge_a[]token_badge_b[writable, signer]funder[writable]whirlpool[writable, signer]token_vault_a[writable, signer]token_vault_b[]fee_tier[]token_program_a[]token_program_b[]system_program[]rent
Implementations
Sourceimpl<'a, 'b> InitializePoolV2CpiBuilder<'a, 'b>
impl<'a, 'b> InitializePoolV2CpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn whirlpools_config( &mut self, whirlpools_config: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_mint_a(&mut self, token_mint_a: &'b AccountInfo<'a>) -> &mut Self
pub fn token_mint_b(&mut self, token_mint_b: &'b AccountInfo<'a>) -> &mut Self
pub fn token_badge_a(&mut self, token_badge_a: &'b AccountInfo<'a>) -> &mut Self
pub fn token_badge_b(&mut self, token_badge_b: &'b AccountInfo<'a>) -> &mut Self
pub fn funder(&mut self, funder: &'b AccountInfo<'a>) -> &mut Self
pub fn whirlpool(&mut self, whirlpool: &'b AccountInfo<'a>) -> &mut Self
pub fn token_vault_a(&mut self, token_vault_a: &'b AccountInfo<'a>) -> &mut Self
pub fn token_vault_b(&mut self, token_vault_b: &'b AccountInfo<'a>) -> &mut Self
pub fn fee_tier(&mut self, fee_tier: &'b AccountInfo<'a>) -> &mut Self
pub fn token_program_a( &mut self, token_program_a: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_program_b( &mut self, token_program_b: &'b AccountInfo<'a>, ) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn rent(&mut self, rent: &'b AccountInfo<'a>) -> &mut Self
pub fn tick_spacing(&mut self, tick_spacing: u16) -> &mut Self
pub fn initial_sqrt_price(&mut self, initial_sqrt_price: u128) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult