pub struct DecreaseLiquidityCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for DecreaseLiquidity via CPI.
Accounts:
[writable]whirlpool[]token_program[signer]position_authority[writable]position[]position_token_account[writable]token_owner_account_a[writable]token_owner_account_b[writable]token_vault_a[writable]token_vault_b[writable]tick_array_lower[writable]tick_array_upper
Implementations
Sourceimpl<'a, 'b> DecreaseLiquidityCpiBuilder<'a, 'b>
impl<'a, 'b> DecreaseLiquidityCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn whirlpool(&mut self, whirlpool: &'b AccountInfo<'a>) -> &mut Self
pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self
pub fn position(&mut self, position: &'b AccountInfo<'a>) -> &mut Self
pub fn position_token_account( &mut self, position_token_account: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_owner_account_a( &mut self, token_owner_account_a: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_owner_account_b( &mut self, token_owner_account_b: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_vault_a(&mut self, token_vault_a: &'b AccountInfo<'a>) -> &mut Self
pub fn token_vault_b(&mut self, token_vault_b: &'b AccountInfo<'a>) -> &mut Self
pub fn tick_array_lower( &mut self, tick_array_lower: &'b AccountInfo<'a>, ) -> &mut Self
pub fn tick_array_upper( &mut self, tick_array_upper: &'b AccountInfo<'a>, ) -> &mut Self
pub fn liquidity_amount(&mut self, liquidity_amount: u128) -> &mut Self
pub fn token_min_a(&mut self, token_min_a: u64) -> &mut Self
pub fn token_min_b(&mut self, token_min_b: u64) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult