This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
Re-exports
pub use self::accounts_type::*;pub use self::adaptive_fee_constants::*;pub use self::adaptive_fee_variables::*;pub use self::lock_type::*;pub use self::lock_type_label::*;pub use self::position_reward_info::*;pub use self::remaining_accounts_info::*;pub use self::remaining_accounts_slice::*;pub use self::tick::*;pub use self::whirlpool_reward_info::*;
Modules
- accounts_
type - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- adaptive_
fee_ constants - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- adaptive_
fee_ variables - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- lock_
type - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- lock_
type_ label - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- position_
reward_ info - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- remaining_
accounts_ info - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- remaining_
accounts_ slice - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- tick
- This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.
- whirlpool_
reward_ info - This code was AUTOGENERATED using the codama library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun codama to update it.